stacker_blueprints
==================

.. image:: https://circleci.com/gh/cloudtools/stacker_blueprints.svg?style=shield
   :target: https://circleci.com/gh/cloudtools/stacker_blueprints

.. image:: https://badge.fury.io/py/stacker_blueprints.svg
   :target: https://badge.fury.io/py/stacker_blueprints

.. image:: https://empire-slack.herokuapp.com/badge.svg
   :target: https://empire-slack.herokuapp.com


An attempt at a common Blueprint library for use with `stacker <https://github.com/cloudtools/stacker>`_.

If you're new to stacker you may use `stacker_cookiecutter <https://github.com/cloudtools/stacker_cookiecutter>`_ to setup your project.
